==> igniteui-webcomponents-core-3.5.0.tgz: package/esm5/lib/PropertyEditorPropertyDescriptionButtonClickEventArgsDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Description } from "./Description";
import { markType } from "./type";
/**
 * @hidden
 */
var PropertyEditorPropertyDescriptionButtonClickEventArgsDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(PropertyEditorPropertyDescriptionButtonClickEventArgsDescription, _super);
    function PropertyEditorPropertyDescriptionButtonClickEventArgsDescription() {
        return _super.call(this) || this;
    }
    PropertyEditorPropertyDescriptionButtonClickEventArgsDescription.prototype.get_type = function () {
        return "PropertyEditorPropertyDescriptionButtonClickEventArgs";
    };
    Object.defineProperty(PropertyEditorPropertyDescriptionButtonClickEventArgsDescription.prototype, "type", {
        get: function () {
            return this.get_type();
        },
        enumerable: true,
        configurable: true
    });
    PropertyEditorPropertyDescriptionButtonClickEventArgsDescription.$t = markType(PropertyEditorPropertyDescriptionButtonClickEventArgsDescription, 'PropertyEditorPropertyDescriptionButtonClickEventArgsDescription', Description.$);
    return PropertyEditorPropertyDescriptionButtonClickEventArgsDescription;
}(Description));
export { PropertyEditorPropertyDescriptionButtonClickEventArgsDescription };

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm5/lib/PropertyEditorPropertyDescriptionButtonClickEventArgsDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Description } from "./Description";
import { markType } from "./type";
/**
 * @hidden
 */
var PropertyEditorPropertyDescriptionButtonClickEventArgsDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(PropertyEditorPropertyDescriptionButtonClickEventArgsDescription, _super);
    function PropertyEditorPropertyDescriptionButtonClickEventArgsDescription() {
        return _super.call(this) || this;
    }
    PropertyEditorPropertyDescriptionButtonClickEventArgsDescription.prototype.get_type = function () {
        return "PropertyEditorPropertyDescriptionButtonClickEventArgs";
    };
    Object.defineProperty(PropertyEditorPropertyDescriptionButtonClickEventArgsDescription.prototype, "type", {
        get: function () {
            return this.get_type();
        },
        enumerable: false,
        configurable: true
    });
    PropertyEditorPropertyDescriptionButtonClickEventArgsDescription.$t = markType(PropertyEditorPropertyDescriptionButtonClickEventArgsDescription, 'PropertyEditorPropertyDescriptionButtonClickEventArgsDescription', Description.$);
    return PropertyEditorPropertyDescriptionButtonClickEventArgsDescription;
}(Description));
export { PropertyEditorPropertyDescriptionButtonClickEventArgsDescription };
